#!/usr/bin/env python
# coding: utf-8

# In[12]:


def hilbert(points, depth, dx, dy):
    '''Add points to draw a hilbert curve.'''
    if depth > 1:  hilbert(points, depth - 1, dy, dx)
    draw_relative(points, dx, dy)
    if depth > 1:  hilbert(points, depth - 1, dx, dy)
    draw_relative(points, dy, dx)
    if depth > 1:  hilbert(points, depth - 1, dx, dy)
    draw_relative(points, -dx, -dy)
    if depth > 1:  hilbert(points, depth - 1, -dy, -dx)


# In[13]:


def draw_relative(points, dx, dy):
    '''Add (dx, dy) to the last point in the points list.'''
    points.append(
        (points[-1][0] + dx, points[-1][1] + dy))


# In[18]:


import tkinter as tk
from tkinter import messagebox
import math

class HilbertApp:
    def __init__(self):
        self.window = tk.Tk()
        self.window.title('hilbert_curve')
        self.window.protocol('WM_DELETE_WINDOW', self.kill_callback)
        self.window.geometry('400x400')

        # Build the UI.
        frame = tk.Frame(self.window)
        frame.pack(side=tk.TOP, anchor=tk.W, padx=3, pady=3)

        label = tk.Label(frame, text='Depth:')
        label.pack(side=tk.LEFT, padx=3)
        self.depth_var = tk.StringVar(value='3')
        entry = tk.Entry(frame, textvariable=self.depth_var, width=3)
        entry.pack(side=tk.LEFT, padx=3)

        button = tk.Button(frame, text='Draw', width=10, command=self.draw)
        button.pack(side=tk.LEFT, padx=10)

        self.canvas = tk.Canvas(self.window, bg='white',
            borderwidth=2, relief=tk.SUNKEN)
        self.canvas.pack(padx=10, pady=(0, 10),
            side=tk.BOTTOM, fill=tk.BOTH, expand=True)

        # If the user presses Enter, draw.
        entry.bind('<Return>', lambda event: self.draw())

        # Display the window.
        self.window.focus_force()
        self.window.mainloop()

    def kill_callback(self):
        # Destroy the tkinter window.
        self.window.destroy()

    def draw(self):
        # Delete any previous drawing objects.
        self.canvas.delete(tk.ALL)

        # Get the desired depth.
        try:
            depth = int(self.depth_var.get())
        except:
            messagebox.showinfo('Depth Error', 'Depth must be an integer between 1 and 10.')
            return
        if depth < 1 or depth > 10:
            messagebox.showinfo('Depth Error', 'Depth must be an integer between 1 and 10.')
            return

        # See how big we can make the curve.
        wid = self.canvas.winfo_width()
        hgt = self.canvas.winfo_height()
        total_length = min(wid, hgt) - 20
        start_x = (wid - total_length) / 2
        start_y = (hgt - total_length) / 2

        # Compute the side length for this level.
        dx = total_length / (2 ** depth - 1)
        dy = 0

        # Create the points list.
        points = [(start_x, start_y)]
        hilbert(points, depth, dx, dy)

        # Draw the polygon.
        self.canvas.create_line(points, width=1, fill='black')


# In[19]:


HilbertApp()
print('Done')


# In[ ]:




